@@ -43,7 +43,7 @@ def _open_file(filename):
         return open(
             _unicode_encode(filename, encoding=_encodings["fs"], errors="strict"), "rb"
         )
-    except IOError as e:
+    except OSError as e:
         func_call = f"open('{_unicode_decode(filename)}')"
         if e.errno == errno.EPERM:
             raise portage.exception.OperationNotPermitted(func_call)
@@ -56,7 +56,6 @@ def _open_file(filename):
 
 
 class _generate_hash_function:
-
     __slots__ = ("_hashobject",)
 
     def __init__(self, hashtype, hashobject, origin="unknown"):
@@ -272,13 +271,11 @@ if "RMD160" not in hashfunc_map or "WHIRLPOOL" not in hashfunc_map:
             ("RMD160", "RIPEMD160"),
             ("WHIRLPOOL", "WHIRLPOOL"),
         ):
-            if local_name not in hashfunc_map and hasattr(
-                mhash, "MHASH_%s" % hash_name
-            ):
+            if local_name not in hashfunc_map and hasattr(mhash, f"MHASH_{hash_name}"):
                 _generate_hash_function(
                     local_name,
                     functools.partial(
-                        mhash.MHASH, getattr(mhash, "MHASH_%s" % hash_name)
+                        mhash.MHASH, getattr(mhash, f"MHASH_{hash_name}")
                     ),
                     origin="mhash",
                 )
@@ -310,10 +307,13 @@ if "STREEBOG256" not in hashfunc_map or "STREEBOG512" not in hashfunc_map:
 _whirlpool_unaccelerated = False
 if "WHIRLPOOL" not in hashfunc_map:
     # Bundled WHIRLPOOL implementation
-    _whirlpool_unaccelerated = True
-    from portage.util.whirlpool import new as _new_whirlpool
+    from portage.util.whirlpool import CWhirlpool, PyWhirlpool
 
-    _generate_hash_function("WHIRLPOOL", _new_whirlpool, origin="bundled")
+    if CWhirlpool.is_available:
+        _generate_hash_function("WHIRLPOOL", CWhirlpool, origin="bundled-c")
+    else:
+        _whirlpool_unaccelerated = True
+        _generate_hash_function("WHIRLPOOL", PyWhirlpool, origin="bundled-py")
 
 
 # There is only one implementation for size
@@ -339,7 +339,7 @@ if os.path.exists(PRELINK_BINARY):
     proc.communicate()
     status = proc.wait()
     if os.WIFEXITED(status) and os.WEXITSTATUS(status) == os.EX_OK:
-        prelink_capable = 1
+        prelink_capable = True
     del cmd, proc, status
 
 
@@ -441,11 +441,11 @@ def _apply_hash_filter(digests, hash_filter):
     @type hash_filter: callable
     """
 
-    verifiable_hash_types = frozenset(digests).intersection(hashfunc_keys)
+    verifiable_hash_types = set(digests).intersection(hashfunc_keys)
+    verifiable_hash_types.discard("size")
     modified = False
     if len(verifiable_hash_types) > 1:
-        verifiable_hash_types.discard("size")
-        for k in verifiable_hash_types:
+        for k in list(verifiable_hash_types):
             if not hash_filter(k):
                 modified = True
                 verifiable_hash_types.remove(k)
@@ -453,7 +453,11 @@ def _apply_hash_filter(digests, hash_filter):
                     break
 
     if modified:
-        digests = {k: v for k, v in digests.items() if k in verifiable_hash_types}
+        digests = {
+            k: v
+            for k, v in digests.items()
+            if k == "size" or k in verifiable_hash_types
+        }
 
     return digests
 
@@ -570,7 +574,7 @@ def perform_checksum(filename, hashname="MD5", calc_prelink=0):
                     f"{hashname} hash function not available (needs dev-python/pycrypto)"
                 )
             myhash, mysize = hashfunc_map[hashname].checksum_file(myfilename)
-        except (OSError, IOError) as e:
+        except OSError as e:
             if e.errno in (errno.ENOENT, errno.ESTALE):
                 raise portage.exception.FileNotFound(myfilename)
             elif e.errno == portage.exception.PermissionDenied.errno:
